==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/eo.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Dosiera MIME-tipo",
    "is" : "estas",
    "is not" : "ne estas",
    "matches" : "kongruas kun",
    "does not match" : "ne kongruas kun",
    "Example: {placeholder}" : "Ekzemplo: {placeholder}",
    "File name" : "Dosiernomo",
    "File size (upload)" : "Dosiergrando (alŝuto)",
    "less" : "malpli",
    "less or equals" : "malpli aŭ egalas al",
    "greater or equals" : "pli aŭ egalas al",
    "greater" : "pli",
    "File system tag" : "Dosiersistema etikedo",
    "is tagged with" : "estas etikedita per",
    "is not tagged with" : "ne estas etikedita per",
    "Select tag…" : "Eleti etikedon...",
    "Request remote address" : "Fora adreso de la peto",
    "matches IPv4" : "kongruas kun IPv4",
    "does not match IPv4" : "ne kongruas kun IPv4",
    "matches IPv6" : "kongruas kun IPv6",
    "does not match IPv6" : "ne kongruas kun IPv6",
    "Request time" : "Horo de la peto",
    "between" : "inter",
    "not between" : "ne inter",
    "Start" : "Komenco",
    "End" : "Fino",
    "Select timezone…" : "Elekti horzonon...",
    "Request URL" : "Retadreso („URL“) de la peto",
    "Predefined URLs" : "Antaŭdifinitaj retadresoj",
    "Files WebDAV" : "Dosieroj WebDAV",
    "Request user agent" : "Retumil-identigilo („user-agent“)",
    "Sync clients" : "Sinkronigaj klientoj",
    "Android client" : "Androida kliento",
    "iOS client" : "iOS-a kliento",
    "Desktop client" : "Labortabla kliento",
    "Thunderbird & Outlook addons" : "Thunderbird-a kaj Outlook-a aldonaĵo",
    "User group membership" : "Grupano",
    "is member of" : "estas membro de",
    "is not member of" : "ne estas membro de",
    "Short rule description" : "Mallong priskribo de regulo",
    "Add rule" : "Aldoni regulon",
    "Reset" : "Restarigi",
    "Save" : "Konservi",
    "Saving…" : "Konservante...",
    "Group list is empty" : "Gruplisto malplenas",
    "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
    "Saved" : "Konservita",
    "Saving failed:" : "Konservado malsukcesis:",
    "Add rule group" : "Aldoni regulgrupon",
    "The given operator is invalid" : "Tiu operaciilo ne eblas",
    "The given regular expression is invalid" : "Tiu regulesprimo ne validas",
    "The given file size is invalid" : "Tiu dosiergrando ne validas",
    "The given tag id is invalid" : "Tiu etikeda identigilo ne validas",
    "The given IP range is invalid" : "Tiu IP-intervalo ne validas",
    "The given IP range is not valid for IPv4" : "Tiu IP-intervalo ne validas rilate al IPv4",
    "The given IP range is not valid for IPv6" : "Tiu IP-intervalo ne validas rilate al IPv6",
    "The given time span is invalid" : "Tiu hora intervalo ne validas",
    "The given start time is invalid" : "Tiu komenca horo ne validas",
    "The given end time is invalid" : "Tiu fina horo ne validas",
    "The given group does not exist" : "Tiu grupo ne ekzistas",
    "Check %s is invalid or does not exist" : "La kontrolo %s ne validas aŭ ne ekzistas",
    "Operation #%s does not exist" : "Operacio n-ro %s ne ekzistas",
    "Operation %s does not exist" : "Operacio %s ne ekzistas",
    "Operation %s is invalid" : "Operacio %s ne validas",
    "Check %s does not exist" : "Kontrolo %s ne ekzistas",
    "Check %s is invalid" : "Kontrolo %s ne validas",
    "Check #%s does not exist" : "Kontrolo n-ro %s ne ekzistas",
    "Tag management" : "Etikeda administrado",
    "Files workflow engine" : "Modulo de dosiera laborfluo",
    "Open documentation" : "Malfermi dokumentaron",
    "Loading…" : "Ŝargante...",
    "Workflow" : "Laborfluo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/eo.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Tiu operaciilo ne eblas",
    "The given regular expression is invalid" : "Tiu regulesprimo ne validas",
    "The given file size is invalid" : "Tiu dosiergrando ne validas",
    "The given tag id is invalid" : "Tiu etikeda identigilo ne validas",
    "The given IP range is invalid" : "Tiu IP-intervalo ne validas",
    "The given IP range is not valid for IPv4" : "Tiu IP-intervalo ne validas rilate al IPv4",
    "The given IP range is not valid for IPv6" : "Tiu IP-intervalo ne validas rilate al IPv6",
    "The given time span is invalid" : "Tiu hora intervalo ne validas",
    "The given start time is invalid" : "Tiu komenca horo ne validas",
    "The given end time is invalid" : "Tiu fina horo ne validas",
    "The given group does not exist" : "Tiu grupo ne ekzistas",
    "Operation #%s does not exist" : "Operacio n-ro %s ne ekzistas",
    "Operation %s does not exist" : "Operacio %s ne ekzistas",
    "Operation %s is invalid" : "Operacio %s ne validas",
    "Check %s does not exist" : "Kontrolo %s ne ekzistas",
    "Check %s is invalid" : "Kontrolo %s ne validas",
    "Check #%s does not exist" : "Kontrolo n-ro %s ne ekzistas",
    "Check %s is invalid or does not exist" : "La kontrolo %s ne validas aŭ ne ekzistas",
    "Predefined URLs" : "Antaŭdifinitaj retadresoj",
    "Files WebDAV" : "Dosieroj WebDAV",
    "Sync clients" : "Sinkronigaj klientoj",
    "Android client" : "Androida kliento",
    "iOS client" : "iOS-a kliento",
    "Desktop client" : "Labortabla kliento",
    "Thunderbird & Outlook addons" : "Thunderbird-a kaj Outlook-a aldonaĵo",
    "File name" : "Dosiernomo",
    "is" : "estas",
    "is not" : "ne estas",
    "matches" : "kongruas kun",
    "does not match" : "ne kongruas kun",
    "File MIME type" : "Dosiera MIME-tipo",
    "File size (upload)" : "Dosiergrando (alŝuto)",
    "less" : "malpli",
    "less or equals" : "malpli aŭ egalas al",
    "greater or equals" : "pli aŭ egalas al",
    "greater" : "pli",
    "Request remote address" : "Fora adreso de la peto",
    "matches IPv4" : "kongruas kun IPv4",
    "does not match IPv4" : "ne kongruas kun IPv4",
    "matches IPv6" : "kongruas kun IPv6",
    "does not match IPv6" : "ne kongruas kun IPv6",
    "File system tag" : "Dosiersistema etikedo",
    "is tagged with" : "estas etikedita per",
    "is not tagged with" : "ne estas etikedita per",
    "Request URL" : "Retadreso („URL“) de la peto",
    "Request time" : "Horo de la peto",
    "between" : "inter",
    "not between" : "ne inter",
    "Request user agent" : "Retumil-identigilo („user-agent“)",
    "User group membership" : "Grupano",
    "is member of" : "estas membro de",
    "is not member of" : "ne estas membro de",
    "Short rule description" : "Mallong priskribo de regulo",
    "Add rule" : "Aldoni regulon",
    "Reset" : "Restarigi",
    "Save" : "Konservi",
    "Saving…" : "Konservante...",
    "Group list is empty" : "Gruplisto malplenas",
    "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
    "Saved" : "Konservita",
    "Saving failed:" : "Konservado malsukcesis:",
    "Add rule group" : "Aldoni regulgrupon",
    "Example: {placeholder}" : "Ekzemplo: {placeholder}",
    "Select tag…" : "Eleti etikedon...",
    "Start" : "Komenco",
    "End" : "Fino",
    "Select timezone…" : "Elekti horzonon...",
    "Workflow" : "Laborfluo",
    "Files workflow engine" : "Modulo de dosiera laborfluo",
    "Open documentation" : "Malfermi dokumentaron",
    "Loading…" : "Ŝargante...",
    "Tag management" : "Etikeda administrado"
},
"nplurals=2; plural=(n != 1);");
